@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -26,6 +26,8 @@
 
 #include <QtCore/qglobal.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3Support)
 
 #ifndef QT_NO_NETWORK
@@ -34,4 +36,6 @@ Q_COMPAT_EXPORT void q3InitNetworkProtocols();
 
 #endif // QT_NO_NETWORK
 
+QT_END_HEADER
+
 #endif // Q3NETWORK_H
