@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the Qt3Support module of the Qt Toolkit.
 **
@@ -27,6 +27,8 @@
 #include <QtCore/qmetaobject.h>
 #include <Qt3Support/q3asciidict.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Qt3SupportLight)
 
 //
@@ -45,4 +47,6 @@ public:
 	{ return (Q3ObjectDictionary&)Q3AsciiDict<QMetaObject>::operator=(dict);}
 };
 
+QT_END_HEADER
+
 #endif // Q3OBJECTDICT_H
