@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -26,6 +26,8 @@
 
 #include <QtCore/qbytearray.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class QBitRef;
@@ -140,4 +142,6 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QBitArray &);
 Q_DECLARE_TYPEINFO(QBitArray, Q_MOVABLE_TYPE);
 Q_DECLARE_SHARED(QBitArray)
 
+QT_END_HEADER
+
 #endif // QBITARRAY_H
