@@ -5,12 +5,12 @@
 #  define QT_EDITION QT_EDITION_OPENSOURCE
 #endif
 
-#define QT_BUILD_KEY "amd64 OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "sparc64 OpenBSD g++-3.* full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
+#define Q_BYTE_ORDER Q_BIG_ENDIAN
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_POINTER_SIZE 8
@@ -45,10 +45,10 @@
 # define QT_NO_NAS
 #endif
 
-#if defined(QT_NO_SXV) && defined(QT_SXV)
-# undef QT_NO_SXV
-#elif !defined(QT_NO_SXV) && !defined(QT_SXV)
-# define QT_NO_SXV
+#if defined(QT_NO_SXE) && defined(QT_SXE)
+# undef QT_NO_SXE
+#elif !defined(QT_NO_SXE) && !defined(QT_SXE)
+# define QT_NO_SXE
 #endif
 
 #if defined(QT_NO_ZLIB) && defined(QT_ZLIB)
