@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -35,6 +35,8 @@
 #include <QtGui/qdrag.h>
 #include <QtCore/qvariant.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QAction;
@@ -489,6 +491,7 @@ public:
 #endif
 
 protected:
+    friend class QApplication;
     QRect rect;
 };
 
@@ -655,4 +658,6 @@ private:
 Q_GUI_EXPORT QDebug operator<<(QDebug, const QEvent *);
 #endif
 
+QT_END_HEADER
+
 #endif // QEVENT_H
